simplify.Subscription

Package simplify :: Class Subscription |
[hide private]
[frames] | no frames]

# Class Subscription

source code

    domain.Domain --+
                    |
                   Subscription

A Subscription object.

Instance Methods | [hide private]
delete(self, *auth_args) Delete this object | source code
update(self, *auth_args) Updates this object | source code
Inherited from `domain.Domain`: `__getitem__`, `__init__`, `__setitem__`, `__str__`, `class_name`, `to_dict`

Static Methods | [hide private]
create(params, *auth_args) Creates an Subscription object | source code
list(criteria=None, *auth_args) Retrieve Subscription objects. | source code
find(object_id, *auth_args) Retrieve a Subscription object from the API | source code

Method Details | [hide private]

### create(params, *auth_args) Static Method | source code
Creates an Subscription object Parameters: `params` - a dict of parameters; valid keys are: `amount`: Amount of the payment in the smallest unit of your currency. Example: 100 = $1.00 `billingCycle`: How the plan is billed to the customer. Values must be AUTO (indefinitely until the customer cancels) or FIXED (a fixed number of billing cycles). [default: AUTO] `billingCycleLimit`: The number of fixed billing cycles for a plan. Only used if the billingCycle parameter is set to FIXED. Example: 4 `coupon`: Coupon ID associated with the subscription `currency`: Currency code (ISO-4217). Must match the currency associated with your account. `currentPeriodEnd`: End date of subscription's current period `currentPeriodStart`: Start date of subscription's current period `customer`: Customer that is enrolling in the subscription. `frequency`: Frequency of payment for the plan. Used in conjunction with frequencyPeriod. Valid values are "DAILY", "WEEKLY", "MONTHLY" and "YEARLY". `frequencyPeriod`: Period of frequency of payment for the plan. Example: if the frequency is weekly, and periodFrequency is 2, then the subscription is billed bi-weekly. `name`: Name describing subscription [max length: 50] `plan`: The ID of the plan that should be used for the subscription. `quantity`: Quantity of the plan for the subscription. [min value: 1] `renewalReminderLeadDays`: If set, how many days before the next billing cycle that a renewal reminder is sent to the customer. If null, then no emails are sent. Minimum value is 7 if set. `source`: Source of where subscription was created `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. `private_api_key` - Private key to use for the API call. If `None`, the value of `simplify.private_key` will be used. Returns: a Subscription object

### delete(self, *auth_args) | source code
Delete this object Parameters: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object.

### list(criteria=None, *auth_args) Static Method | source code
Retrieve Subscription objects. Parameters: `criteria` - a dict of parameters; valid keys are: `filter` <table class="filter_list"><tr><td>filter.customer</td><td>Filter by the Id of the customer with the subscription</td></tr><tr><td>filter.plan</td><td>Filter by the Id of the plan linked to the subscription</td></tr><tr><td>filter.dateCreatedMin<sup>*</sup></td><td>Filter by the minimum created date you are searching for - Date in UTC millis</td></tr><tr><td>filter.dateCreatedMax<sup>*</sup></td><td>Filter by the maximum created date you are searching for - Date in UTC millis</td></tr><tr><td>filter.q</td><td>You can use this to filter by the Id, the name or the amount of the subscription</td></tr></table><br><sup>*</sup>Use dateCreatedMin with dateCreatedMax in the same filter if you want to search between two created dates `max` Allows up to a max of 50 list items to return. [min value: 0, max value: 50, default: 20] `offset` Used in paging of the list. This is the start offset of the page. [min value: 0, default: 0] `sorting` Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either `asc` for ascending or `desc` for descending). Sortable properties are: `dateCreated` `id` `plan`. `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: an object which contains the list of Subscription objects in the <code>list</code> property and the total number of objects available for the given criteria in the <code>total</code> property.

### find(object_id, *auth_args) Static Method | source code
Retrieve a Subscription object from the API Parameters: `object_id` - ID of object to retrieve `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a Subscription object

### update(self, *auth_args) | source code
Updates this object The properties that can be updated: `amount` Amount of the payment in the smallest unit of your currency. Example: 100 = $1.00 `billingCycle` How the plan is billed to the customer. Values must be AUTO (indefinitely until the customer cancels) or FIXED (a fixed number of billing cycles). [default: AUTO] `billingCycleLimit` The number of fixed billing cycles for a plan. Only used if the billingCycle parameter is set to FIXED. Example: 4 `coupon` Coupon being assigned to this subscription `currency` Currency code (ISO-4217). Must match the currency associated with your account. `currentPeriodEnd` End date of subscription's current period `currentPeriodStart` Start date of subscription's current period `frequency` Frequency of payment for the plan. Used in conjunction with frequencyPeriod. Valid values are "DAILY", "WEEKLY", "MONTHLY" and "YEARLY". `frequencyPeriod` Period of frequency of payment for the plan. Example: if the frequency is weekly, and periodFrequency is 2, then the subscription is billed bi-weekly. [min value: 1] `name` Name describing subscription `plan` Plan that should be used for the subscription. `prorate` Whether to prorate existing subscription. [default: true] (required) `quantity` Quantity of the plan for the subscription. [min value: 1] `renewalReminderLeadDays` If set, how many days before the next billing cycle that a renewal reminder is sent to the customer. If null or 0, no emails are sent. Minimum value is 7 if set. Parameters: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a Subscription object.